# Using Default Options

## Example

```python
{!./src/options/options.py!}
```

## Running

Running the server:

```bash
uvicorn myapp:app
```

```
{!./src/server.bash.output!}
```

## Quering the route options

```bash
{!./src/options/options_curl.bash!}
```

```
{!./src/options/options_curl.bash.output!}
```

## Quering the app options

```bash
{!./src/options/options_curl2.bash!}
```

```
{!./src/options/options_curl2.bash.output!}
```

